import {select, csv, scaleLinear, extent, scaleTime, area, max, min,
        axisLeft, axisBottom, format, curveBasis} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = dd => {
  const xValue = d => d.year;
  const xLabel = 'Year';
  const yValue = d => d.population;
  const yLabel = 'Population';
  const circleRadius = 10;
  const margin = {top:50, right:50, bottom:100, left: 150};
  const innerwidth = width-margin.right-margin.left;
  const innerheight = height-margin.top-margin.bottom
  
  const xScale = scaleTime()
  	.domain([min(dd, xValue), max(dd, xValue)])
  	.range([0, innerwidth]);
  
  const yScale = scaleLinear()
  	.domain([0, max(dd, yValue)])
  	.range([innerheight, 0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const areaGenerator = area()
  	.x(pick => xScale(xValue(pick)))
  	.y0(innerheight)
  	.y1(pick => yScale(yValue(pick)))
  	.curve(curveBasis);
  
  	
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', areaGenerator(dd))
  
  const xAxis = axisBottom(xScale)
  	.ticks(7)
  	.tickSize(-innerheight)
  	.tickPadding(15);
  
  const yAxisFormat = number => 
  	format('.1s')(number)
  		.replace('G', 'B');

  const yAxis = axisLeft(yScale)
  	.tickSize(-innerwidth)
  	.tickPadding(5)
  	.tickFormat(yAxisFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  
  
   
  yAxisG.selectAll('.domain')
  		.remove();
    
   yAxisG.append('text')
  	.attr('y',-80)
  	.attr('x', -innerheight/2)
  	.attr('fill', 'black')
  	.attr('transform', `rotate(-90)`)
  	.style('text-anchor', 'middle')
  	.text(yLabel);
  	 
  const xAxisG = g.append('g').call(xAxis)
 		.attr('transform', `translate(0, ${innerheight})`);
  
  
 xAxisG.selectAll('.domain').remove();
  
 xAxisG.append('text')
  	.attr('y',50)
  	.attr('x', innerwidth /2)
  	.attr('fill', 'black')
  	.text(xLabel);
  
  g.append('text')
  	.attr('class', 'title')
  	.attr('y', -10)
  	.attr('x', innerwidth/2)
		.text('World Population - Area Chart');
  
};

	

csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv')
  .then(data => { console.log(data)
  data.forEach(d => {
    d.population = +d.population;
    d.year = new Date(d.year);
  })
	render(data)
});



